@@ -41,19 +41,28 @@ pub(crate) fn encode(
             rmp::encode::write_str(&mut encoded, service_name)?;
 
             rmp::encode::write_str(&mut encoded, "name")?;
-            rmp::encode::write_str(&mut encoded, span.instrumentation_lib.name)?;
+            rmp::encode::write_str(&mut encoded, span.instrumentation_lib.name.as_ref())?;
 
             rmp::encode::write_str(&mut encoded, "resource")?;
             rmp::encode::write_str(&mut encoded, &span.name)?;
 
             rmp::encode::write_str(&mut encoded, "trace_id")?;
-            rmp::encode::write_u64(&mut encoded, span.span_context.trace_id().to_u128() as u64)?;
+            rmp::encode::write_u64(
+                &mut encoded,
+                u128::from_be_bytes(span.span_context.trace_id().to_bytes()) as u64,
+            )?;
 
             rmp::encode::write_str(&mut encoded, "span_id")?;
-            rmp::encode::write_u64(&mut encoded, span.span_context.span_id().to_u64())?;
+            rmp::encode::write_u64(
+                &mut encoded,
+                u64::from_be_bytes(span.span_context.span_id().to_bytes()),
+            )?;
 
             rmp::encode::write_str(&mut encoded, "parent_id")?;
-            rmp::encode::write_u64(&mut encoded, span.parent_span_id.to_u64())?;
+            rmp::encode::write_u64(
+                &mut encoded,
+                u64::from_be_bytes(span.parent_span_id.to_bytes()),
+            )?;
 
             rmp::encode::write_str(&mut encoded, "start")?;
             rmp::encode::write_i64(&mut encoded, start)?;
